[PATCH] D16692: [OpenCL] Eliminate warning when declaring OpenCL builtin functions

Yaxun Liu via cfe-commits cfe-commits at lists.llvm.org
Fri Jan 29 10:19:53 PST 2016


yaxunl updated this revision to Diff 46395.
yaxunl marked an inline comment as done.
yaxunl added a comment.

revised as Anastasia suggested.


http://reviews.llvm.org/D16692

Files:
  lib/Sema/SemaLookup.cpp
  test/SemaOpenCL/builtin.cl

Index: test/SemaOpenCL/builtin.cl
===================================================================
--- /dev/null
+++ test/SemaOpenCL/builtin.cl
@@ -0,0 +1,3 @@
+// RUN: %clang_cc1 %s -verify -pedantic -fsyntax-only
+
+float __attribute__((overloadable)) acos(float); // expected-no-diagnostics
Index: lib/Sema/SemaLookup.cpp
===================================================================
--- lib/Sema/SemaLookup.cpp
+++ lib/Sema/SemaLookup.cpp
@@ -684,9 +684,9 @@

       // If this is a builtin on this (or all) targets, create the decl.
       if (unsigned BuiltinID = II->getBuiltinID()) {
-        // In C++, we don't have any predefined library functions like
-        // 'malloc'. Instead, we'll just error.
-        if (S.getLangOpts().CPlusPlus &&
+        // In C++ and OpenCL (spec v1.2 s6.9.f), we don't have any predefined
+        // library functions like 'malloc'. Instead, we'll just error.
+        if ((S.getLangOpts().CPlusPlus || S.getLangOpts().OpenCL) &&
             S.Context.BuiltinInfo.isPredefinedLibFunction(BuiltinID))
           return false;



-------------- next part --------------
A non-text attachment was scrubbed...
Name: D16692.46395.patch
Type: text/x-patch
Size: 1082 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/cfe-commits/attachments/20160129/11c1d82c/attachment.bin>


More information about the cfe-commits mailing list